import { GamePropsSchema } from "@lib/zodSchemas"
import { useSession } from "next-auth/react"
import { useEffect, useState } from "react"
import { toast } from "react-toastify"

function useGameState(initial?: GamePropsSchema) {
  const [gameProps, setGameProps] = useState<GamePropsSchema>(
    initial ?? { payload: {}, hash: "" }
  )
  const { data: session, status } = useSession()

  useEffect(() => {
    if (status === "loading") return
    if (!session)
      toast("Nicht angemeldet.", {
        toastId: "user",
        position: "top-center",
      })
    else
      toast(session.user.email, {
        toastId: "user",
        position: "top-center",
        icon: session.user.image ? (
          <img
            style={{ transform: "scale(1.5)", borderRadius: "100%" }}
            src={session.user.image}
            alt="profile picture"
          />
        ) : undefined,
      })
  }, [session, status])

  return {
    gameProps,
    setGameProps,
    session,
    status,
  }
}

export default useGameState
