import BurgerMenu from "../../components/BurgerMenu"
import LobbyFrame from "../../components/Lobby/LobbyFrame"
import Settings from "../../components/Lobby/SettingsFrame/Settings"
import Logo from "../../components/Logo"
import { Data, composeBody, getAnyRunningGame } from "../api/game/running"
import useGameState from "@lib/hooks/useGameState"
import classNames from "classnames"
import { GetServerSideProps } from "next"
import Head from "next/head"
import { useState } from "react"

export default function Home(props: Data) {
  const [settings, setSettings] = useState(false)
  const { gameProps, setGameProps } = useGameState(props)

  return (
    <div className="h-full bg-theme">
      <Head>
        <title>Lobby</title>
        <meta name="description" content="Generated by create next app" />
        <meta name="viewport" content="width=device-width, initial-scale=1" />
        <link rel="icon" href="/favicon.ico" />
      </Head>
      <div
        className={classNames(
          "mx-auto flex h-full max-w-screen-2xl flex-col items-center justify-evenly",
          { "blur-sm": settings }
        )}
      >
        <Logo small={true} />
        <LobbyFrame openSettings={() => setSettings(true)} />
      </div>
      <BurgerMenu blur={settings} />
      {settings ? <Settings closeSettings={() => setSettings(false)} /> : <></>}
    </div>
  )
}

export const getServerSideProps: GetServerSideProps<Data> = async (context) => {
  const { gameId } = context.query

  const gameIdString = Array.isArray(gameId) ? gameId[0] : gameId
  const game = await getAnyRunningGame(gameIdString ?? "")
  if (!game)
    return {
      redirect: {
        destination: "/start",
        permanent: false,
      },
    }
  const body = composeBody(game)

  return { props: body }
}
